import attr
import enum
import maya
import json
import html2text
from datetime import datetime
from cvss import CVSS3
from typing import List
from ..constants import PLATFORM_ICONS

ATTACHMENT_IMAGE_FORMATS = ['png', 'jpg', 'jpeg', 'bmp', 'svg', 'gif']


class PlatformEnum(enum.Enum):
    ANDROID = 'Android'
    IOS = 'iOS'
    WINDOWS = 'Windows'


class PlatformIconEnum(enum.Enum):
    ANDROID = PLATFORM_ICONS['ANDROID']
    IOS = PLATFORM_ICONS['IOS']
    WINDOWS = PLATFORM_ICONS['WINDOWS']


class RiskColorEnum(enum.Enum):
    CRITICAL = '#EF4836'
    HIGH = '#FF8C00'
    MEDIUM = '#F5D76E'
    LOW = '#2CC2F8'
    PASSED = '#80C081'
    UNTESTED = '#6B6B6B'


class RiskValueEnum(enum.Enum):
    CRITICAL = 4
    HIGH = 3
    MEDIUM = 2
    LOW = 1
    PASSED = 0
    UNTESTED = -1


class RiskLabelEnum(enum.Enum):
    CRITICAL = 'Critical'
    HIGH = 'High'
    MEDIUM = 'Medium'
    LOW = 'Low'
    PASSED = 'Passed'
    UNTESTED = 'Untested'


class AnalysisTypeEnum(enum.Enum):
    STATIC = 'Static'
    DYNAMIC = 'Dynamic'
    MANUAL = 'Manual'
    API = 'API'


class AttackVectorEnum(enum.Enum):
    N = 'NETWORK'
    A = 'ADJACENT_NETWORK'
    L = 'LOCAL'
    P = 'PHYSICAL'


class AttackComplexityEnum(enum.Enum):
    H = 'HIGH'
    L = 'LOW'


class PrivilegesRequiredEnum(enum.Enum):
    H = 'HIGH'
    L = 'LOW'
    N = 'NONE'


class UserInteractionEnum(enum.Enum):
    N = 'NONE'
    R = 'REQUIRED'


class ScopeEnum(enum.Enum):
    U = 'UNCHANGED'
    C = 'CHANGED'


class ConfidentialityImpactEnum(enum.Enum):
    H = 'HIGH'
    L = 'LOW'
    N = 'NONE'


class IntegrityImpactEnum(enum.Enum):
    H = 'HIGH'
    L = 'LOW'
    N = 'NONE'


class AvailabilityImpactEnum(enum.Enum):
    H = 'HIGH'
    L = 'LOW'
    N = 'NONE'


@attr.s
class Platform:
    ANDROID = PlatformEnum.ANDROID.value
    IOS = PlatformEnum.IOS.value
    WINDOWS = PlatformEnum.WINDOWS.value
    ICON_ANDROID = PlatformIconEnum.ANDROID.value
    ICON_IOS = PlatformIconEnum.IOS.value
    ICON_WINDOWS = PlatformIconEnum.WINDOWS.value
    name = attr.ib(type=str)
    icon = attr.ib(type=str)


@attr.s
class Application:
    name = attr.ib(type=str)
    icon = attr.ib(type=str)
    version = attr.ib(type=str)
    version_code = attr.ib(type=int)
    sha1 = attr.ib(type=str)
    md5 = attr.ib(type=str)


@attr.s
class Company:
    name = attr.ib(type=str, default='')
    logo = attr.ib(type=str, default='')
    hide = attr.ib(type=bool, default=False)


@attr.s
class Reference:
    id = attr.ib(type=int)
    name = attr.ib(type=str)
    url = attr.ib(type=str)


@attr.s
class CustomMetaData:
    key = attr.ib(type=str)
    val = attr.ib(type=str)


@attr.s
class Content:
    html = attr.ib(type=str)
    text = attr.ib(type=str, default='')
    markdown = attr.ib(type=str, default='')

    def html_to_text(self):
        return html2text.html2text(self.html)[:-2]


@attr.s
class Attachment:
    id = attr.ib(type=str)
    name = attr.ib(type=str)
    extension = attr.ib(type=str)
    url = attr.ib(type=str)


@attr.s
class CVSSv3:
    version = attr.ib(type=str)
    vector_string = attr.ib(type=str)
    base_score = attr.ib(type=str)
    base_severity = attr.ib(type=str)
    attack_vector = attr.ib(
        type=str,
        validator=attr.validators.in_([e.value for e in AttackVectorEnum]),
        default=AttackVectorEnum.P.value
    )
    attack_complexity = attr.ib(
        type=str,
        validator=attr.validators.in_([e.value for e in AttackComplexityEnum]),
        default=AttackComplexityEnum.H.value
    )
    privileges_required = attr.ib(
        type=str,
        validator=attr.validators.in_(
            [e.value for e in PrivilegesRequiredEnum]
        ),
        default=PrivilegesRequiredEnum.H.value
    )
    user_interaction = attr.ib(
        type=str,
        validator=attr.validators.in_([e.value for e in UserInteractionEnum]),
        default=UserInteractionEnum.R.value
    )
    scope = attr.ib(
        type=str,
        validator=attr.validators.in_([e.value for e in ScopeEnum]),
        default=ScopeEnum.U.value
    )
    confidentiality_impact = attr.ib(
        type=str,
        validator=attr.validators.in_(
            [e.value for e in ConfidentialityImpactEnum]
        ),
        default=ConfidentialityImpactEnum.N.value
    )
    integrity_impact = attr.ib(
        type=str,
        validator=attr.validators.in_([e.value for e in IntegrityImpactEnum]),
        default=IntegrityImpactEnum.N.value
    )
    availability_impact = attr.ib(
        type=str,
        validator=attr.validators.in_(
            [e.value for e in AvailabilityImpactEnum]
        ),
        default=AvailabilityImpactEnum.N.value
    )

    @classmethod
    def parse_vector(cls, vector_string: str) -> 'CVSSv3':
        if not vector_string:
            return None
        cvssv3 = CVSS3(vector_string)
        (
            base_severity, temporal_severity, environmental_severity
        ) = cvssv3.severities()
        return CVSSv3(
            version='3',
            vector_string=vector_string,
            base_score=str(cvssv3.base_score),
            base_severity=base_severity,
            attack_vector=(
                AttackVectorEnum[cvssv3.metrics.get('AV')].value
            ),
            attack_complexity=(
                AttackComplexityEnum[cvssv3.metrics.get('AC')].value
            ),
            privileges_required=(
                PrivilegesRequiredEnum[cvssv3.metrics.get('PR')].value
            ),
            user_interaction=(
                UserInteractionEnum[cvssv3.metrics.get('UI')].value
            ),
            scope=(
                ScopeEnum[cvssv3.metrics.get('S')].value
            ),
            confidentiality_impact=(
                ConfidentialityImpactEnum[cvssv3.metrics.get('C')].value
            ),
            integrity_impact=(
                IntegrityImpactEnum[cvssv3.metrics.get('I')].value
            ),
            availability_impact=(
                AvailabilityImpactEnum[cvssv3.metrics.get('A')].value
            ),
        )


@attr.s
class Risk:
    value = attr.ib(type=int, default=RiskValueEnum.UNTESTED.value)
    value_label = attr.ib(type=str, default=RiskLabelEnum.UNTESTED.value)
    value_color = attr.ib(type=str, default=RiskColorEnum.UNTESTED.value)
    computed_value = attr.ib(
        type=int, default=RiskValueEnum.UNTESTED.value
    )
    computed_value_label = attr.ib(
        type=str, default=RiskLabelEnum.UNTESTED.value
    )
    computed_value_color = attr.ib(
        type=str, default=RiskColorEnum.UNTESTED.value
    )
    is_overridden = attr.ib(type=bool, default=False)
    override_comment = attr.ib(type=str, default='')


@attr.s
class OWASP:
    code = attr.ib(type=str)
    year = attr.ib(type=int)
    title = attr.ib(type=str)


@attr.s
class PCIDSS:
    code = attr.ib(type=str)
    title = attr.ib(type=str)
    description = attr.ib(type=str)


@attr.s
class Regulatory:
    owasp = attr.ib(factory=list, type=List[dict])
    pcidss = attr.ib(factory=list, type=List[dict])

    @classmethod
    def from_json(cls, data):
        return cls(
            owasp=[OWASP(**owasp) for owasp in data.get('owasp', [])],
            pcidss=[PCIDSS(**pcidss) for pcidss in data.get('pcidss', [])]
        )

    @classmethod
    def create_owasp(cls, code: str, year: int, title: str) -> OWASP:
        return OWASP(code=code, year=year, title=title)

    @classmethod
    def create_pcidss(cls, code: str, title: str, description: str) -> PCIDSS:
        return PCIDSS(code=code, title=title, description=description)

    def add_owasp(self, owasp: OWASP) -> List[OWASP]:
        self.owasp.append(owasp)
        return self.owasp

    def add_pcidss(self, pcidss: PCIDSS) -> List[PCIDSS]:
        self.pcidss.append(pcidss)
        return self.pcidss


@attr.s
class Tag:
    val = attr.ib(type=str)


@attr.s
class Finding:
    title = attr.ib(type=Content)
    description = attr.ib(type=Content)


@attr.s
class Analysis:
    id = attr.ib(type=int)
    title = attr.ib(type=Content)
    desc = attr.ib(type=Content)
    intro = attr.ib(type=Content)
    business_implication = attr.ib(type=Content)
    correct_implementation = attr.ib(type=Content)
    incorrect_implementation = attr.ib(type=Content)
    vulnerability_references = attr.ib(type=Content)
    risk = attr.ib(type=Risk, default=Risk())
    cvss_v3 = attr.ib(type=CVSSv3, default=None)
    regulatory = attr.ib(
        type=Regulatory, default=Regulatory(owasp=[], pcidss=[])
    )
    findings = attr.ib(factory=list, type=List[Content])
    tags = attr.ib(factory=list, type=List[Tag])
    attachments = attr.ib(factory=list, type=List[Attachment])

    @classmethod
    def from_json(cls, data):
        cvssv3 = data.get('cvss_v3')
        return cls(
            id=data.get('id'),
            title=Content(**data.get('title')),
            desc=Content(**data.get('desc')),
            intro=Content(**data.get('intro')),
            business_implication=Content(**data.get('business_implication')),
            correct_implementation=Content(
                **data.get('correct_implementation')
            ),
            incorrect_implementation=Content(
                **data.get('incorrect_implementation')
            ),
            vulnerability_references=Content(
                **data.get('vulnerability_references')
            ),
            risk=Risk(**data.get('risk', {})),
            cvss_v3=CVSSv3(**cvssv3) if cvssv3 else None,
            regulatory=Regulatory.from_json(data.get('regulatory')),
            findings=[
                cls.create_finding(
                    title=Content(**finding.get('title')),
                    description=Content(**finding.get('description'))
                )
                for finding in data.get('findings', [])
            ],
            tags=[Tag(**tag) for tag in data.get('tags', [])],
            attachments=[
                Attachment(**attachment)
                for attachment in data.get('attachments', [])
            ]
        )

    @classmethod
    def create_regulatory(
        cls, owasp: List[dict]=[], pcidss: List[dict]=[]
    ) -> Regulatory:
        return Regulatory(owasp=owasp, pcidss=pcidss)

    @classmethod
    def create_attachment(
        cls, id: str, name: str, extension: str, url: str
    ) -> Attachment:
        return Attachment(id=id, name=name, extension=extension, url=url)

    @classmethod
    def create_finding(cls, title: Content, description: Content) -> Finding:
        if title.html:
            title.html = cls.trim_unsupported_chars(title.html)
        if description.html:
            description.html = cls.trim_unsupported_chars(description.html)
        return Finding(title=title, description=description)

    @classmethod
    def create_tag(cls, val: str) -> Tag:
        return Tag(val=val)

    @classmethod
    def create_risk(
        cls, value: int, value_label: str, value_color: str,
        computed_value: int, computed_value_label: str,
        computed_value_color: str, is_overridden: bool, override_comment: str
    ) -> Risk:
        return Risk(
            value=value,
            value_label=value_label,
            value_color=value_color,
            computed_value=computed_value,
            computed_value_label=computed_value_label,
            computed_value_color=computed_value_color,
            is_overridden=is_overridden,
            override_comment=override_comment
        )

    def add_finding(self, finding: Finding) -> Finding:
        self.findings.append(finding)
        return self.findings

    def add_tag(self, tag: Tag) -> Tag:
        self.tags.append(tag)
        return self.tags

    def remove_tag(self, tag_val: str) -> Tag:
        for t in self.tags:
            if tag_val == t.val:
                self.tags.remove(t)
        return self.tags

    def add_attachment(self, attachment: Attachment) -> Attachment:
        if attachment.extension.lower() not in ATTACHMENT_IMAGE_FORMATS:
            return False
        self.attachments.append(attachment)
        return self.attachments

    @classmethod
    def trim_unsupported_chars(cls, string: str) -> str:
        """trim non-font characters"""
        s = string
        for char in ['\u001b', '\\u001b', '\x1b']:  # ESCAPE char
            s = s.replace(char, '')
        return s


@attr.s
class Report:
    COLOR_CRITICAL = RiskColorEnum.CRITICAL.value
    COLOR_HIGH = RiskColorEnum.HIGH.value
    COLOR_MEDIUM = RiskColorEnum.MEDIUM.value
    COLOR_LOW = RiskColorEnum.LOW.value
    COLOR_PASSED = RiskColorEnum.PASSED.value
    COLOR_UNTESTED = RiskColorEnum.UNTESTED.value
    RISK_COLOR = {
        'critical': COLOR_CRITICAL,
        'high': COLOR_HIGH,
        'medium': COLOR_MEDIUM,
        'low': COLOR_LOW,
        'passed': COLOR_PASSED,
        'untested': COLOR_UNTESTED,
    }
    package_name = attr.ib(type=str)
    platform = attr.ib(type=Platform)
    application = attr.ib(type=Application)
    appknox_file_id = attr.ib(type=int, default=None)
    prepared_for = attr.ib(
        type=Company,
        default=Company(name='')
    )
    prepared_by = attr.ib(
        type=Company,
        default=Company(
            name='Appknox', logo='https://appknox.com/in/img/logo.png'
        )
    )
    powered_by = attr.ib(
        type=Company,
        default=Company(hide=True)
    )
    created_on = attr.ib(
        type=datetime,
        default=maya.now().iso8601()
    )
    show_copyright = attr.ib(type=bool, default=True)
    is_partnered = attr.ib(type=bool, default=False)
    rating = attr.ib(type=int, default=0)
    has_static_scan = attr.ib(type=bool, default=True)
    has_dynamic_scan = attr.ib(type=bool, default=True)
    has_api_scan = attr.ib(type=bool, default=True)
    has_manual_scan = attr.ib(type=bool, default=True)
    references = attr.ib(factory=list, type=List[Reference])
    custom_meta_data = attr.ib(factory=list, type=List[CustomMetaData])
    analyses = attr.ib(factory=list, type=List[Analysis])

    def to_dict(self) -> dict:
        return attr.asdict(self)

    def to_json(self) -> dict:
        return json.loads(
            json.dumps(self.to_dict(), indent=4, sort_keys=True, default=str)
        )

    @classmethod
    def from_json(cls, data):
        return cls(
            package_name=data.get('package_name'),
            platform=Platform(**data.get('platform')),
            application=Application(**data.get('application')),
            appknox_file_id=data.get('appknox_file_id'),
            prepared_for=Company(**data.get('prepared_for')),
            prepared_by=Company(**data.get('prepared_by')),
            powered_by=Company(**data.get('powered_by')),
            created_on=cls.create_created_on(data.get('created_on')),
            show_copyright=data.get('show_copyright'),
            is_partnered=data.get('is_partnered'),
            rating=data.get('rating'),
            references=[
                Reference(**reference)
                for reference in data.get('references', [])
            ],
            custom_meta_data=[
                CustomMetaData(**cmd)
                for cmd in data.get('custom_meta_data', [])
            ],
            analyses=[
                Analysis.from_json(analysis)
                for analysis in data.get('analyses', [])
            ],
        )

    def add_analysis(self, analysis: Analysis) -> Analysis:
        self.analyses.append(analysis)

    def add_reference(self, reference: Reference) -> Reference:
        self.references.append(reference)

    def add_custom_metadata(
        self, customdata: CustomMetaData
    ) -> CustomMetaData:
        self.custom_meta_data.append(customdata)

    @classmethod
    def create_platform(cls, name: str, icon: str) -> Platform:
        return Platform(name=name, icon=icon)

    @classmethod
    def create_application(
        cls, name: str, icon: str, version: str, version_code: str,
        sha1: str, md5: str
    ) -> Application:
        return Application(
            name=name, icon=icon, version=version, version_code=version_code,
            sha1=sha1, md5=md5
        )

    @classmethod
    def create_company(cls, name, logo, hide) -> Company:
        return Company(name=name, logo=logo, hide=hide)

    @classmethod
    def create_created_on(
        cls, isodate: str=(maya.now().iso8601())
    ) -> datetime:
        return maya.parse(isodate).datetime()

    @classmethod
    def create_reference(cls, id: int, name: str, url: str) -> Reference:
        return Reference(id=id, name=name, url=url)

    @classmethod
    def create_custommetadata(cls, key: str, val: str) -> CustomMetaData:
        return CustomMetaData(key=key, val=val)

    @classmethod
    def create_analysis(
        cls, id, title: Content, intro: Content, desc: Content,
        risk: Risk, cvss_v3: CVSSv3, business_implication: Content,
        correct_implementation: Content, incorrect_implementation: Content,
        regulatory: Regulatory, vulnerability_references: Content,
        findings: List[Content]=[], tags: List[Tag]=[],
        attachments: List[Attachment]=[]
    ) -> Analysis:
        return Analysis(
            id=id,
            title=title,
            intro=intro,
            desc=desc,
            risk=risk,
            cvss_v3=cvss_v3,
            business_implication=business_implication,
            correct_implementation=correct_implementation,
            incorrect_implementation=incorrect_implementation,
            regulatory=regulatory,
            vulnerability_references=vulnerability_references,
            findings=findings,
            tags=tags,
            attachments=attachments
        )

    @classmethod
    def create_content(
        cls, text: str='', html: str='', markdown: str=''
    ) -> Content:
        return Content(text=text, html=html, markdown=markdown)

    @classmethod
    def create_risk(cls, **kwargs) -> Risk:
        return Analysis.create_risk(**kwargs)

    @classmethod
    def create_regulatory(cls, **kwargs) -> Regulatory:
        return Analysis.create_regulatory(**kwargs)

    @classmethod
    def parse_cvssv3_vector(cls, **kwargs) -> CVSSv3:
        return CVSSv3.parse_vector(**kwargs)

    @classmethod
    def get_risk_color(cls, risk: str) -> str:
        return cls.RISK_COLOR.get(risk.lower(), '')

    def _count_severity(self, label: str) -> int:
        count = 0
        for a in self.analyses:
            if a.risk and (a.risk.computed_value_label.lower() == label):
                count += 1
        return count

    def _percent_severity(self, count: int) -> float:
        if not len(self.analyses):
            return 0.0
        return round((count / len(self.analyses)) * 100, 2)

    @property
    def critical_count(self) -> int:
        return self._count_severity('critical')

    @property
    def high_count(self) -> int:
        return self._count_severity('high')

    @property
    def medium_count(self) -> int:
        return self._count_severity('medium')

    @property
    def low_count(self) -> int:
        return self._count_severity('low')

    @property
    def passed_count(self) -> int:
        return self._count_severity('passed')

    @property
    def untested_count(self) -> int:
        return self._count_severity('untested')

    @property
    def critical_percent(self) -> float:
        return self._percent_severity(self.critical_count)

    @property
    def high_percent(self) -> float:
        return self._percent_severity(self.high_count)

    @property
    def medium_percent(self) -> float:
        return self._percent_severity(self.medium_count)

    @property
    def low_percent(self) -> float:
        return self._percent_severity(self.low_count)

    @property
    def passed_percent(self) -> float:
        return self._percent_severity(self.passed_count)

    @property
    def untested_percent(self) -> float:
        return self._percent_severity(self.untested_count)

    @property
    def svg_chart(self) -> str:
        tpl = (
            '<circle cx="21" cy="21" r="15.91549430918954" stroke-width="8" '
            'stroke="{}" stroke-dasharray="{} {}" stroke-dashoffset="-{}" '
            'fill="transparent"></circle>'
        )
        sector = ''
        offset = 0
        p = self.critical_percent
        sector += tpl.format(self.COLOR_CRITICAL, p, round(100 - p, 2), offset)
        offset += p
        p = self.high_percent
        sector += tpl.format(self.COLOR_HIGH, p, round(100 - p, 2), offset)
        offset += p
        p = self.medium_percent
        sector += tpl.format(self.COLOR_MEDIUM, p, round(100 - p, 2), offset)
        offset += p
        p = self.low_percent
        sector += tpl.format(self.COLOR_LOW, p, round(100 - p, 2), offset)
        offset += p
        p = self.passed_percent
        sector += tpl.format(self.COLOR_PASSED, p, round(100 - p, 2), offset)
        offset += p
        p = self.untested_percent
        sector += tpl.format(self.COLOR_UNTESTED, p, round(100 - p, 2), offset)
        return (
            'data:image/svg+xml;utf8,'
            '<svg xmlns="http://www.w3.org/2000/svg" '
            'xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" '
            'width="216px" height="216px" viewBox="0 0 42 42">{}</svg>'
        ).format(sector)

    @property
    def custom_meta_names(self) -> [str]:
        return [
            cmd.val for cmd in self.custom_meta_data
            if cmd.key == 'name' and cmd.val != ''
        ]

    @property
    def _scan_types_visible(self) -> {str}:
        scan_types = set()
        if self.has_static_scan:
            scan_types.add(AnalysisTypeEnum.STATIC.value.lower())
        if self.has_dynamic_scan:
            scan_types.add(AnalysisTypeEnum.DYNAMIC.value.lower())
        if self.has_api_scan:
            scan_types.add(AnalysisTypeEnum.API.value.lower())
        if self.has_manual_scan:
            scan_types.add(AnalysisTypeEnum.MANUAL.value.lower())
        return scan_types

    def _is_visible_scan_type(self, analysis):
        tags = {t.val.lower() for t in analysis.tags}
        include_tags = tags.intersection(self._scan_types_visible)
        if not include_tags:
            return False
        if include_tags:
            for t in analysis.tags:
                if t.val.lower() not in include_tags:
                    analysis.tags.remove(t)
        return analysis

    @property
    def viewable_analyses(self) -> List[Analysis]:
        return [a for a in self.analyses if self._is_visible_scan_type(a)]



from gettext import gettext as _


data = [
  {
    "title": _(
        "Install and maintain a firewall and router configuration to protect"
        "cardholder data"
    ),
    "code": "1.1",
    "id": "1_1",
    "description": _(
        "Establish firewall and router configuration standards that formalize "
        "testing whenever configurations change; that identify all "
        "connections to cardholder data (including wireless); that use "
        "various technical settings for each implementation; and stipulate "
        "a review of configuration rule sets at least every six months."
    )
  },
  {
    "title": _(
        "Install and maintain a firewall and router configuration to protect "
        "cardholder data"
    ),
    "code": "1.2",
    "id": "1_2",
    "description": _(
        "Build firewall and router configurations that restrict "
        "all traffic from untrusted networks and hosts, except for protocols "
        "necessary for the cardholder data environment."
    )
  },
  {
    "title": _(
        "Install and maintain a firewall and router configuration to protect "
        "cardholder data"
    ),
    "code": "1.3",
    "id": "1_3",
    "description": _(
        "Prohibit direct public access between the Internet and any system "
        "component in the cardholder data environment."
    )
  },
  {
    "title": _(
        "Install and maintain a firewall and router configuration to protect "
        "cardholder data"
    ),
    "code": "1.4",
    "id": "1_4",
    "description": _(
        "Install personal firewall software on any mobile and/or "
        "employee-owned computers with direct connectivity to the Internet "
        "that are used to access the organization's network"
    )
  },
  {
    "title": _(
        "Do not use vendor-supplied defaults for system passwords and other "
        "security parameters"
    ),
    "code": "2.1",
    "id": "2_1",
    "description": _(
        "Always change vendor-supplied defaults before installing a system "
        "on the network. This includes wireless devices that are connected "
        "to the cardholder data environment or are used to transmit "
        "cardholder data"
    )
  },
  {
    "title": _(
        "Do not use vendor-supplied defaults for system passwords and other "
        "security parameters"
    ),
    "code": "2.2",
    "id": "2_2",
    "description": _(
        "Develop configuration standards for all system components that "
        "address all known security vulnerabilities and are consistent with "
        "industry-accepted definitions. Update system configuration standards "
        "as new vulnerability issues are identified."
    )
  },
  {
    "title": _(
        "Do not use vendor-supplied defaults for system passwords and other "
        "security parameters"
    ),
    "code": "2.3",
    "id": "2_3",
    "description": _(
        "Encrypt using strong cryptography all non-console administrative "
        "access such as browser/web- based management tools"
    )
  },
  {
    "title": _(
        "Do not use vendor-supplied defaults for system passwords and other "
        "security parameters"
    ),
    "code": "2.4",
    "id": "2_4",
    "description": _(
        "Shared hosting providers must protect each entity's hosted "
        "environment and cardholder data (details are in PCI DSS Appendix A: "
        "Additional PCI DSS Requirements for Shared Hosting Providers.)"
    )
  },
  {
    "title": _("Protect stored cardholder data"),
    "code": "3.1",
    "id": "3_1",
    "description": _(
        "Limit cardholder data storage and retention time to that required "
        "for business, legal, and/or regulatory purposes, as documented in "
        "your data retention policy. Purge unnecessary stored data at least "
        "quarterly."
    )
  },
  {
    "title": _("Protect stored cardholder data"),
    "code": "3.2",
    "id": "3_2",
    "description": _(
        "Do not store sensitive authentication data after authorization"
        " (even if it is encrypted). See guidelines in table below. Issuers "
        "and related entities may store sensitive authentication data if "
        "there is a business justification, and the data is stored securely."
    )
  },
  {
    "title": _("Protect stored cardholder data"),
    "code": "3.3",
    "id": "3_3",
    "description": _(
        "Mask PAN when displayed; the first six and last four digits are the "
        "maximum number of digits you may display. Not applicable for "
        "authorized people with a legitimate business need to see the full "
        "PAN. Does not supersede stricter requirements in place for displays "
        "of cardholder data such as on a point-of-sale receipt."
    )
  },
  {
    "title": _("Protect stored cardholder data"),
    "code": "3.4",
    "id": "3_4",
    "description": _(
        "Render PAN unreadable anywhere it is stored including on portable "
        "digital media, backup media, in logs, and data received from or "
        "stored by wireless networks. Technology solutions for this "
        "requirement may include strong one-way hash functions of the "
        "entire PAN, truncation, index tokens with securely stored pads, "
        "or strong cryptography. (See PCI DSS Glossary for definition of "
        "strong cryptography.)"
    )
  },
  {
    "title": _("Protect stored cardholder data"),
    "code": "3.5",
    "id": "3_5",
    "description": _(
        "Protect any keys used for encryption of cardholder data from "
        "disclosure and misuse"
    )
  },
  {
    "title": _("Protect stored cardholder data"),
    "code": "3.6",
    "id": "3_6",
    "description": _(
        "Fully document and implement all appropriate key management "
        "processes and procedures for cryptographic keys used for encryption "
        "of cardholder data"
    )
  },
  {
    "title": _(
        "Encrypt transmission of cardholder data across open, public networks"
    ),
    "code": "4.1",
    "id": "4_1",
    "description": _(
        "Use strong cryptography and security protocols such as SSL/TLS, SSH "
        "or IPSec to safeguard sensitive cardholder data during transmission "
        "over open, public networks (e.g. Internet, wireless technologies, "
        "Global System for Mobile communications [GSM], General Packet Radio "
        "Service [GPRS]). Ensure wireless networks transmitting cardholder "
        "data or connected to the cardholder data environment use industry "
        "best practices (e.g., IEEE 802.11i) to implement strong encryption "
        "for authentication and transmission. The use of WEP as a security "
        "control is prohibited"
    )
  },
  {
    "title": _(
        "Encrypt transmission of cardholder data across open, public networks"
    ),
    "code": "4.2",
    "id": "4_2",
    "description": _(
        "Never send unprotected PANs by end user messaging technologies"
    )
  },
  {
    "title": _("Use and regularly update anti-virus software or programs"),
    "code": "5.1",
    "id": "5_1",
    "description": _(
        "Deploy anti-virus software on all systems affected by malicious "
        "software (particularly personal computers and servers)"
    )
  },
  {
    "title": _("Use and regularly update anti-virus software or programs"),
    "code": "5.2",
    "id": "5_2",
    "description": _(
        "Ensure that all anti-virus mechanisms are current, actively running, "
        "and generating audit logs"
    )
  },
  {
    "title": _("Develop and maintain secure systems and applications"),
    "code": "6.1",
    "id": "6_1",
    "description": _(
        "Ensure that all system components and software are protected from "
        "known vulnerabilities by having the latest vendor-supplied security "
        "patches installed. Deploy critical patches within a month of release"
    )
  },
  {
    "title": _("Develop and maintain secure systems and applications"),
    "code": "6.2",
    "id": "6_2",
    "description": _(
        "Establish a process to identify and assign a risk ranking to newly "
        "discovered security vulnerabilities. Risk rankings should be based "
        "on industry best practices and guidelines."
    )
  },
  {
    "title": _("Develop and maintain secure systems and applications"),
    "code": "6.3",
    "id": "6_3",
    "description": _(
        "Develop software applications (internal and external, and including "
        "web-based administrative access) in accordance with PCI DSS and "
        "based on industry best practices. Incorporate information security "
        "throughout the software development life cycle."
    )
  },
  {
    "title": _("Develop and maintain secure systems and applications"),
    "code": "6.4",
    "id": "6_4",
    "description": _(
        "Follow change control processes and procedures for all changes to "
        "system components"
    )
  },
  {
    "title": _("Develop and maintain secure systems and applications"),
    "code": "6.5",
    "id": "6_5",
    "description": _(
        "Develop applications based on secure coding guidelines and review "
        "custom application code to identify coding vulnerabilities. "
        "Follow up-to-date industry best practices to identify and manage "
        "vulnerabilities."
    )
  },
  {
    "title": _("Develop and maintain secure systems and applications"),
    "code": "6.6",
    "id": "6_6",
    "description": _(
        "Ensure all public-facing web applications are protected against "
        "known attacks, either by performing code vulnerability reviews at "
        "least annually or by installing a web application firewall in front "
        "of public-facing web applications"
    )
  },
  {
    "title": _("Restrict access to cardholder data by business need to know"),
    "code": "7.1",
    "id": "7_1",
    "description": _(
        "Limit access to system components and cardholder data to only those "
        "individuals whose job requires such access."
    )
  },
  {
    "title": _("Restrict access to cardholder data by business need to know"),
    "code": "7.2",
    "id": "7_2",
    "description": _(
        "Establish an access control system for systems components with "
        "multiple users that restricts access based on a user's need to know, "
        "and is set to deny all unless specifically allowed"
    )
  },
  {
    "title": _("Assign a unique ID to each person with computer access"),
    "code": "8.1",
    "id": "8_1",
    "description": _(
        "Assign all users a unique user name before allowing them to access "
        "system components or cardholder data."
    )
  },
  {
    "title": _("Assign a unique ID to each person with computer access"),
    "code": "8.2",
    "id": "8_2",
    "description": _(
        "Employ at least one of these to authenticate all users: something "
        "you know, such as a password or passphrase; something you have, "
        "such as a token device or smart card; or something you are, "
        "such as a biometric"
    )
  },
  {
    "title": _("Assign a unique ID to each person with computer access"),
    "code": "8.3",
    "id": "8_3",
    "description": _(
        "Implement two-factor authentication for remote access to the network "
        "by employees, administrators, and third parties. For example, use "
        "technologies such as remote authentication and dialin service "
        "(RADIUS) with tokens; terminal access controller access control "
        "system (TACACS) with tokens; or other technologies that facilitate "
        "two-factor authentication. Using one factor twice (e.g. using two "
        "separate passwords) is not considered two-factor authentication"
    )
  },
  {
    "title": _("Assign a unique ID to each person with computer access"),
    "code": "8.4",
    "id": "8_4",
    "description": _(
        "Render all passwords unreadable during storage and transmission, "
        "for all system components, by using strong cryptography."
    )
  },
  {
    "title": _("Assign a unique ID to each person with computer access"),
    "code": "8.5",
    "id": "8_5",
    "description": _(
        "Ensure proper user identification and authentication management for "
        "non-consumer users and administrators on all system components"
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.1",
    "id": "9_1",
    "description": _(
        "Use appropriate facility entry controls to limit and monitor "
        "physical access to systems in the cardholder data environment"
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.2",
    "id": "9_2",
    "description": _(
        "Develop procedures to easily distinguish between onsite personnel "
        "and visitors, especially in areas where cardholder data is accessible"
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.3",
    "id": "9_3",
    "description": _(
        "Ensure all visitors are authorized before entering areas where "
        "cardholder data is processed or maintained; given a physical token "
        "that expires and that identifies visitors as not onsite personnel; "
        "and are asked to surrender the physical token before leaving the "
        "facility or at the date of expiration."
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.4",
    "id": "9_4",
    "description": _(
        "Use a visitor log to maintain a physical audit trail of visitor "
        "information and activity, including visitor name and company, and "
        "the onsite personnel authorizing physical access. Retain the log "
        "for at least three months unless otherwise restricted by law."
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.5",
    "id": "9_5",
    "description": _(
        "Store media back-ups in a secure location, preferably off site."
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.6",
    "id": "9_6",
    "description": _(
        "Physically secure all media."
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.7",
    "id": "9_7",
    "description": _(
        "Maintain strict control over the internal or external distribution "
        "of any kind of media. Classify media so the sensitivity of the data "
        "can be determined."
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.8",
    "id": "9_8",
    "description": _(
        "Ensure that management approves any and all media moved from a "
        "secured area, especially when media is distributed to individuals"
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.9",
    "id": "9_9",
    "description": _(
        "Maintain strict control over the storage and accessibility of media"
    )
  },
  {
    "title": _("Restrict physical access to cardholder data"),
    "code": "9.10",
    "id": "9._0",
    "description": _(
        "Destroy media when it is no longer needed for business or legal "
        "reasons"
    )
  },
  {
    "title": _(
        "Track and monitor all access to network resources and cardholder  "
        "data"
    ),
    "code": "10.1",
    "id": "10_1",
    "description": _(
        "Establish a process for linking all access to system components "
        "to each individual user especially access done with administrative "
        "privileges."
    )
  },
  {
    "title": _(
        "Track and monitor all access to network resources and cardholder  "
        "data"
    ),
    "code": "10.2",
    "id": "10_2",
    "description": _(
        "Implement automated audit trails for all system components for "
        "reconstructing these events: all individual user accesses to "
        "cardholder data; all actions taken by any individual with root or "
        "administrative privileges; access to all audit trails; invalid "
        "logical access attempts; use of identification and authentication "
        "mechanisms; initialization of the audit logs; creation and "
        "deletion of system-level objects"
    )
  },
  {
    "title": _(
        "Track and monitor all access to network resources and cardholder  "
        "data"
    ),
    "code": "10.3",
    "id": "10_3",
    "description": _(
        "Record audit trail entries for all system components for each event, "
        "including at a minimum: user identification, type of event, date and "
        "time, success or failure indication, origination of event, and "
        "identity or name of affected data, system component or resource. "
    )
  },
  {
    "title": _(
        "Track and monitor all access to network resources and cardholder  "
        "data"
    ),
    "code": "10.4",
    "id": "10_4",
    "description": _(
        "Using time synchronization technology, synchronize all critical "
        "system clocks and times and implement controls for acquiring, "
        "distributing, and storing time."
    )
  },
  {
    "title": _(
        "Track and monitor all access to network resources and cardholder  "
        "data"
    ),
    "code": "10.5",
    "id": "10_5",
    "description": _(
        "Secure audit trails so they cannot be altered."
    )
  },
  {
    "title": _(
        "Track and monitor all access to network resources and cardholder  "
        "data"
    ),
    "code": "10.6",
    "id": "10_6",
    "description": _(
        "Review logs for all system components related to security functions "
        "at least daily"
    )
  },
  {
    "title": _(
        "Track and monitor all access to network resources and cardholder  "
        "data"
    ),
    "code": "10.7",
    "id": "10_7",
    "description": _(
        "Retain audit trail history for at least one year; at least three "
        "months of history must be immediately available for analysis"
    )
  },
  {
    "title": _("Regularly test security systems and processes"),
    "code": "11.1",
    "id": "11_1",
    "description": _(
        "Test for the presence of wireless access points and detect "
        "unauthorized wireless access points on a quarterly basis. "
        "Typical methods are wireless network scans, physical/logical "
        "inspections of system components and infrastructure, network "
        "access control (NAC), or wireless IDS/IPS. "
    )
  },
  {
    "title": _("Regularly test security systems and processes"),
    "code": "11.2",
    "id": "11_2",
    "description": _(
        "Run internal and external network vulnerability scans at least "
        "quarterly and after any significant change in the network. After "
        "passing a scan for initial PCI DSS compliance, an entity must, in "
        "subsequent years, pass four consecutive quarterly scans as a "
        "requirement for compliance. Quarterly external scans must be "
        "performed by an Approved Scanning Vendor (ASV). Scans conducted "
        "after network changes may be performed by internal staff"
    )
  },
  {
    "title": _("Regularly test security systems and processes"),
    "code": "11.3",
    "id": "11_3",
    "description": _(
        "Perform external and internal penetration testing, including "
        "network- and application-layer penetration tests, at least "
        "annually and after any significant infrastructure or application "
        "upgrade or modification."
    )
  },
  {
    "title": _("Regularly test security systems and processes"),
    "code": "11.4",
    "id": "11_4",
    "description": _(
        "Use network intrusion detection systems and/or intrusion prevention "
        "systems to monitor all traffic at the perimeter of the cardholder "
        "data environment as well as at critical points inside of the "
        "cardholder data environment, and alert personnel to suspected "
        "compromises. IDS/IPS engines, baselines, and signatures must be "
        "kept up to date"
    )
  },
  {
    "title": _("Regularly test security systems and processes"),
    "code": "11.5",
    "id": "11_5",
    "description": _(
        "Deploy file integrity monitoring tools to alert personnel to "
        "unauthorized modification of critical system files, configuration "
        "files or content files. Configure the software to perform critical "
        "file comparisons at least weekly"
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.1",
    "id": "12_1",
    "description": _(
        "Establish, publish, maintain, and disseminate a security policy "
        "that addresses all PCI DSS requirements, includes an annual "
        "process for identifying vulnerabilities and formally assessing "
        "risks, and includes a review at least once a year and when the "
        "environment changes"
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.2",
    "id": "12_2",
    "description": _(
        "Develop daily operational security procedures that are consistent "
        "with requirements in PCI DSS"
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.3",
    "id": "12_3",
    "description": _(
        "Develop usage policies for critical technologies to define their "
        "proper use by all personnel. These include remote access, wireless, "
        "removable electronic media, laptops, tablets, handheld devices, "
        "email and Internet"
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.4",
    "id": "12_4",
    "description": _(
        "Ensure that the security policy and procedures clearly define "
        "information security responsibilities for all personnel."
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.5",
    "id": "12_5",
    "description": _(
        "Assign to an individual or team information security "
        "responsibilities defined by 12.5 subsections."
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.6",
    "id": "12_6",
    "description": _(
        "Implement a formal security awareness program to make all "
        "personnel aware of the importance of cardholder data security"
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.7",
    "id": "12_7",
    "description": _(
        "Screen potential personnel prior to hire to minimize the risk of "
        "attacks from internal sources. Example screening includes previous "
        "employment history, criminal record, credit history, and reference "
        "checks"
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.8",
    "id": "12_8",
    "description": _(
        "If cardholder data is shared with service providers, maintain "
        "policies and procedures to formally identify service provider "
        "responsibilities for securing cardholder data, and monitor service "
        "providers' PCI DSS compliance status at least annually"
    )
  },
  {
    "title": _(
        "Maintain a policy that addresses information security for all "
        "personnel"
    ),
    "code": "12.9",
    "id": "12_9",
    "description": _(
        "Implement an incident response plan. Be prepared to respond "
        "immediately to a system breach."
    )
  }
]



#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# vim: fenc=utf-8
# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
#
#
# flake8: noqa

"""
File name: seed.py
Author: dhilipsiva <dhilipsiva@gmail.com>
Date created: 2017-03-30
"""
from copy import copy
from ak_vendor import owasp
from ak_vendor import pcidss
from ak_vendor.utils import dict2obj
OWASP_DATA = {d['id']: dict2obj(d) for d in owasp.data}
PCIDSS_DATA = {d['id']: dict2obj(d) for d in pcidss.data}


vulnerability_template = {
    'business_implication': '<p>With Cordova 3.5.0 or prior, attackers may:</p><p>Para2 With Cordova 3.5.0 or prior, attackers may:</p><ul><li>Open and send data to arbitrary applications.</li><li>Bypass the HTTP whitelist and connect to arbitrary servers.</li><li>Change the start page via a crafted intent URL.</li></ul>',
    'compliant': '<p>Ensure that the <code>android:debuggable</code> attribute is set to false before the app is released:</p>\n<pre><code>android:debuggable=&quot;false&quot;</code></pre>\n<p>Note that some development environments (including Eclipse/ADT and Ant) automatically set <code>android:debuggable</code> to true for incremental or debugging builds but set it to false for release builds.</p>\n',
    'description': '<p>Debugging was enabled on the app which makes it easier for reverseengineers to hook a debugger to it. This allows dumping a stack traceand accessing debugging helper classes.</p>',
    'heading': 'Do not release apps that are debuggable',
    'intro': '<p>Android allows the attribute <code>android:debuggable</code> to be set to true so that the app can be debugged. By default this attribute is disabled, i.e., it is set to false, but it may be set to true to help with debugging during development of the app. However, an app should never be released with this attribute set to true as it enables users to gain access to details of the app that should be kept secure. With the attribute set to true, users can debug the app even without access to its source code.</p>\n',
    'name': 'Application Debug Enabled',
    'non_compliant': '<p>This non-compliant code example shows an app that has the <code>android:debuggable</code> attribute set to true being accessed to reveal sensitive data.</p>\n<pre><code>$ adb shell\nshell@android:/ $ run-as com.example.someapp sh\nshell@android:/data/data/com.example.someapp $ id\nuid=10060(app_60) gid=10060(app_60)\nshell@android:/data/data/com.example.someapp $ ls files/\nsecret_data.txt\nshell@android:/data/data/com.example.some $ cat files/secret_data.txt\npassword=GoogolPlex\naccount_number=31974286</code></pre>\n<p>Clearly, with the <code>android:debuggable</code> attribute set to true, sensitive date related to the app can be revealed to any user.</p>\n',
    'question': 'Does the application has Debug enabled?',
    'related_to': '<p>With Cordova 3.5.0 or prior, attackers may:</p><p>Para2 With Cordova 3.5.0 or prior, attackers may:</p><ul><li>Open and send data to arbitrary applications.</li><li>Bypass the HTTP whitelist and connect to arbitrary servers.</li><li>Change the start page via a crafted intent URL.</li></ul>',
    'success_message': 'Debugging was disabled',
    'get_types_display': ["Static","Dynamic","API","Manual"],
    'uuid': '84b86ac9-a60e-40ef-ab1b-fc8ec39f6e1d',
    'id': 3
}



analysis_template = {
    'analiser_version': 0,
    'created_on': '2017-03-03 09:17:31.849832+00:00',
    'findings': [
        {'title': None, 'description': 'This application opens a socket and connects to it, which might be insecured, defined at Lcom/e/a/a/a/q;->b'},
        {'title': None, 'description': 'This application opens a socket and connects to it, which might be insecured, defined at Lcom/e/a/a/a/p;->a'},
        {'title': None, 'description': 'This application opens a socket and connects to it, which might be insecured, defined at Lcom/e/a/a/a/p;->d'},
        {'title': None, 'description': 'This application opens a socket and connects to it, which might be insecured, defined at Lcom/e/a/a/a/p;->f'},
        {'title': "Debug was enabled on the app which make it easier for attackers to hook a debugger, dump a stack trace and access debugging helper classes.", "description": "<application android:debuggable='true' Debug enabled for app"},
    ],
    'risk': 3,
    'status': 1,
    'updated_on': '2017-03-03 09:18:14.704847+00:00',
    'uuid': '9d522cf6-ce5c-4bef-9d96-2e641c2e65be',
    'id': 135,
    'vulnerability': vulnerability_template,
    'color': 'red',
    'computed_risk': 3,
    'get_risk_display': 'High',
    'get_computed_risk_display': 'High',
    'is_ignored': True,
    'show_cvss': 'True',
    'cvss_base': 6.7,
    'cvss_version': 3,
    'cvss_metrics_humanized': [
        {'key': 'Integrity Impact', 'value': 'Low'},
        {'key': 'Attack Vector', 'value': 'Network'},
        {'key': 'Availability Impact', 'value': 'None'},
        {'key': 'Confidentiality Impact', 'value': 'Low'},
        {'key': 'Attack Complexity', 'value': 'Low'},
        {'key': 'User Interaction', 'value': 'Not Required'},
        {'key': 'Privileges Required', 'value': 'High'}
    ],
    'owasp': ['M1_2016', 'M10_2016', 'A1_2013'],
    'owasp_categories': [
        OWASP_DATA.get('M1_2016'), OWASP_DATA.get('M10_2016'),
        OWASP_DATA.get('A1_2013')
    ],
    'pcidss': ['1_1', '1_2', '1_3', '1_4'],
    'pcidss_categories': [
        PCIDSS_DATA.get('1_1'),
        PCIDSS_DATA.get('1_2'),
        PCIDSS_DATA.get('1_3'),
        PCIDSS_DATA.get('1_4')
    ]
 }

analiser1 = copy(analysis_template)
analiser2 = copy(analysis_template)
vulnerability1 = copy(vulnerability_template)
vulnerability2 = copy(vulnerability_template)

vulnerability2['name'] = 'Unprotected Services'
vulnerability2['related_to'] = '<ul> <li>Facebook SDK for Android: <a href="http://readwrite.com/2012/04/10/what-developers-and-users-can#awesm=~o9iqZAMlUPshPu" class="uri">http://readwrite.com/2012/04/10/what-developers-and-users-can#awesm=~o9iqZAMlUPshPu</a></li> <li><a href="https://jvn.jp/en/jp/JVN23328321/">JVN#23328321</a> Puella Magi Madoka Magica iP for Android vulnerable to information disclosure</li> <li><a href="https://jvn.jp/en/jp/JVN86040029/">JVN#86040029</a> Weathernews Touch for Android stores location information in the system log file</li> <li><a href="https://jvn.jp/en/jp/JVN33159152/">JVN#33159152</a> Loctouch for Android information management vulnerability</li> <li><a href="https://jvn.jp/en/jp/JVN56923652/">JVN#56923652</a> Monaca Debugger for Android information management vulnerability</li> </ul>'
vulnerability2['non_compliant'] = '<ol style="list-style-type: decimal"> <li>Facebook SDK for Android contained the following code which sends Facebook access tokens to log output in plain text format.</p> <pre><code>Log.d(&quot;Facebook-authorize&quot;, &quot;Login Success! access_token=&quot; + getAccessToken() + &quot; expires=&quot; + getAccessExpires());</code></pre></li> <li><p>Here is another example. A weather report for Android sent a user\'s location data to the log output as follows:</p> <pre><code>I/MyWeatherReport( 6483): Re-use MyWeatherReport data I/ ( 6483): GET JSON: http://example.com/smart/repo_piece.cgi?arc=0&amp;lat=26.209026&amp;lon=127.650803&amp;rad=50&amp;dir=-999&amp;lim=52&amp;category=1000</code></pre> <p>If a user is using Android OS 4.0 or before, other applications with READ_LOGS permission can obtain the user\'s location information without declaring ACCESS_FINE_LOCATION permission in the manifest file.</p></li> </ol>'

analiser2['risk'] = 3
analiser2['overriden_risk'] = 4
analiser2['computed_risk'] = 4
analiser2['is_ignored'] = False
analiser2['get_computed_risk_display'] = 'Critical'
vulnerability2['get_types_display'] = ["Static","Dynamic"]

analiser1['vulnerability'] = vulnerability1
analiser2['vulnerability'] = vulnerability2

file_data = {
    'created_on': '2017-03-03 09:17:31.568125+00:00',
    'device_token': 'None',
    'dynamic_status': 0,
    'icon_url': 'assets/icon.png',
    'is_dynamic_done': False,
    'is_static_done': False,
    'manual': 0,
    'md5hash': '97d83c689f2cb0118e1901054165e8fe',
    'name': 'FooBar',
    'sha1hash': 'd5341a898eb1d1e90a316d49e8f6b4f33ad08cf0',
    'updated_on': '2017-03-03 09:17:31.568149+00:00',
    'uuid': '04b8fa5d-2ea9-4055-b862-5b470640ffa2',
    'version': '1.0',
    'version_code': '1',
    'id': 29,
    'sorted_analyses': [analiser1, analiser2],
    'project': {
        'get_platform_display': 'iOS',
        'platform': 1,
        'package_name': 'com.google.android.youtube.com.google.bar'
    },
    'risk_count_critical': 12,
    'risk_count_high': 10,
    'risk_count_medium': 7,
    'risk_count_low': 8,
    'profile': {
        'report_preference': {
            'show_ignored_analyses': True
        }
    }
}


report_data = {
    'client': {
        'name': 'Google',
        'logo': 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/2f/Google_2015_logo.svg/272px-Google_2015_logo.svg.png',
    },
    'partner': {
        'name': 'Django',
        'logo': 'https://www.djangoproject.com/s/img/logos/django-logo-positive.png',
        'hide_poweredby_logo': False,
    },
    'whitelabel': {
        'name': 'Django',
        'logo': '',
        'enabled': True,
        'hide_poweredby_logo': False,
    },
    'author': {
        'name': 'Appknox',
        'logo': 'https://raw.githubusercontent.com/appknox/press-kit/master/logo/logo-dark-small.png'
    },
    'show_copyright': False
}
